/**-----------------------------------------------------------------------------

  File         :  dwt_utils.c
  Description  :  Useful functions using DWT unit
  Author       :  Aleksander Borysiuk

  History:
  - 2017.06.11 - ver. 1.0

------------------------------------------------------------------------------*/
/*------------------------------------------------------------------------------
  Hardware info:
  Data Watchpoint and Trace unit is implemented in Cortex-M3/M4/M7 cores. It
  contains clock cycle counter (CYCCNT) that can be used by application for
  measuring time periods.
------------------------------------------------------------------------------*/

/* Includes ------------------------------------------------------------------*/
#include "dwt_utils.h"

/* Private define ------------------------------------------------------------*/

/* Private variables ---------------------------------------------------------*/

/* Private function prototypes -----------------------------------------------*/

/* Private functions ---------------------------------------------------------*/

/* Public functions ----------------------------------------------------------*/
/**-----------------------------------------------------------------------------
  Name         :  dwt_Delay
  Description  :  Calibrated delay routine
                  Delay time is measured by the clock cycle counter in DWT unit
  Argument(s)  :  nTime: delay time length (in us)
  Return value :  none
------------------------------------------------------------------------------*/
void dwt_Delay(uint32_t nTime)
{
  // Calculate number of SYS clocks
  nTime = (DWT_CLK / 1000000) * nTime;

  // Reset cycle counter
  DWT->CYCCNT = 0;

  // Start counting
  DWT->CTRL |= DWT_CTRL_CYCCNTENA_Msk;

  // Wait
  while(DWT->CYCCNT < nTime);

  // Stop counting
  DWT->CTRL &= ~DWT_CTRL_CYCCNTENA_Msk;
}

/*----------------------------- End of file ----------------------------------*/
