/**-----------------------------------------------------------------------------

  Name         :  i2c_stm32f1.h
  Description  :  Header file for i2c driver for STM32F1 microcontroller
  Author       :  Aleksander Borysiuk

  History      :  2017.03.18 - Start of the project
                             - Driver ver.1.0
                  2017.06.08 - Static i2c data buffer substituted by pointer
                               to external data buffer
                  2017.07.15 - Added delay for i2c controller reset
                             - Added reset of the i2c controller if problem with
                               sending START condition is detected
                             - Drvier ver.1.2

------------------------------------------------------------------------------*/

#ifndef _i2c_STM32F1_H_
#define _i2c_STM32F1_H_

/* Includes ------------------------------------------------------------------*/
#include "stm32f10x.h"

/* Exported macro ------------------------------------------------------------*/
// i2c peripheral
#define I2C_INTFC_NO         1         // i2c peripheral number (1: I2C1, 2: I2C2)
#define I2C_INTFC            I2C1      // i2c peripheral (I2C1 or I2C2)
#define I2C_INTFC_CLK        RCC_APB1ENR_I2C1EN // i2c peripheral clock
#define I2C_INTFC_FREQ       36000000  // i2c peripheral clock frequency in Hz
#define I2C_BUS_FREQ         400000    // i2c bus clock in Hz (max. 400KHz)

// i2c port and I/O lines
#define I2C_GPIO             GPIOB
#define I2C_GPIO_CLK         RCC_APB2ENR_IOPBEN
#define I2C_GPIO_REMAP       0         // GPIO pin remapping (only for I2C1)
                                       // 0 - default, 1 - remap

#define I2C_SCL              6         // SCL : i2c clock
#define I2C_SDA              7         // SDA : i2c data

/* Exported types ------------------------------------------------------------*/
typedef struct{
  uint8_t device_addr;                 // i2c device address
  uint8_t data_adr;                    // i2c data address
  uint8_t data_size;                   // data size
  uint8_t *pdata;                      // data buffer address
} i2c_DataTypeDef;

/* Public functions ----------------------------------------------------------*/
void i2c_Init(void);
uint8_t i2c_WriteData(i2c_DataTypeDef *pI2C_data);
uint8_t i2c_ReadData(i2c_DataTypeDef *pI2C_data);

#endif // _i2c_STM32F1_H_
/*----------------------------- End of file ----------------------------------*/
