/**-----------------------------------------------------------------------------

  Name         :  lcdHEM6432.h
  Description  :  Header file for HEM6432-03 64x32 graphic LCD driver
                  for STM32F1 microcontroller
  Author       :  Aleksander Borysiuk

  History      :  2017.06.11 - Start of the project
                  2017.06.16 - LCD driver ver.1.0

------------------------------------------------------------------------------*/

#ifndef __lcdHEM6432_H
#define __lcdHEM6432_H

/* Includes ------------------------------------------------------------------*/
#include "stm32f10x.h"

/* Exported macro ------------------------------------------------------------*/
// HEM6432 LCD module GPIO port and signal lines
// - LCD i2c interface lines (i.e. I2C_SCL and I2C_SDA) are configured in
//   i2c_stm32f1 module

// - LCD RST line
#define LCD_RST_GPIO         GPIOD
#define LCD_RST_GPIO_CLK     RCC_APB2ENR_IOPDEN
#define LCD_RST_PIN          3

// HEM6432 LCD module orientation
// Uncomment #define if LCD module orientation is upside down. Otherwise LCD
// module orientation is normal.
//#define LCD_UPSIDE_DOWN              // LCD module orientation upside down

/* Exported types ------------------------------------------------------------*/

/* Exported constants --------------------------------------------------------*/

/* Exported functions ------------------------------------------------------- */
void lcdHEM6432_Init(void);
void lcdHEM6432_RefreshCfg(void);
void lcdHEM6432_SetContrast(uint8_t contrast);
void lcdHEM6432_SetNormalDisplay(void);
void lcdHEM6432_SetInvertedDisplay(void);
void lcdHEM6432_SetPowerSaveON(void);
void lcdHEM6432_SetPowerSaveOFF(void);
void lcdHEM6432_GoToXY(uint8_t Xpos, uint8_t Ypos);
void lcdHEM6432_Clean(void);
void lcdHEM6432_PutChar(uint8_t char_code);
void lcdHEM6432_PutText(uint8_t *text);
void lcdHEM6432_PutBMP(uint8_t *pPicture);

#endif // __lcdHEM6432_H
/*----------------------------- End of file ----------------------------------*/
